import React from 'react';
import PropTypes from 'prop-types';
import { Row } from '@comparaonline/ui-grid';
import Title from './Title';
import SubTitle from './SubTitle';
import {
  HeroHeaderWrapper,
  ColumnHeader,
  TitleContainer,
  BreadcrumbsContainer
} from './Layout';

const HeroHeader = props => {
  const { title, subTitle, backgroundImages, breadcrumbs } = props;

  return (
    <HeroHeaderWrapper>
      <Row equalHeightColumns>
        <ColumnHeader medium={12} backgroundImages={backgroundImages}>
          <BreadcrumbsContainer>{breadcrumbs}</BreadcrumbsContainer>
          <TitleContainer>
            {title && (
              <Title>
                {title}
                {subTitle && <SubTitle>{subTitle}</SubTitle>}
              </Title>
            )}
          </TitleContainer>
        </ColumnHeader>
      </Row>
    </HeroHeaderWrapper>
  );
};

HeroHeader.propTypes = {
  title: PropTypes.node.isRequired,
  subTitle: PropTypes.node,
  backgroundImages: PropTypes.shape({
    small: PropTypes.string.isRequired,
    large: PropTypes.string.isRequired
  }).isRequired,
  breadcrumbs: PropTypes.node
};

HeroHeader.defaultProps = {
  subTitle: null,
  breadcrumbs: null
};

export default HeroHeader;
